@@ -214,13 +214,6 @@ battery_device_cache_entry_update_all (GpmPower *power, GpmPowerDevice *entry)
 		if (exists) {
 			status->charge_rate_smoothed = status->charge_rate_raw;
 		}
-		/* FIXME: following can be removed if bug #5752 of hal on freedesktop
-		   gets fixed and is part of a new release of HAL and we depend on that
-		   version*/
-		if (exists && status->charge_rate_raw == 0) {
-			status->is_discharging = FALSE;
-			status->is_charging = FALSE;
-		}
 	}
 
 	/* sanity check that charge_level.percentage exists (if it should) */
@@ -356,13 +349,6 @@ battery_device_cache_entry_update_key (GpmPower		       *power,
 							power->priv->exp_ave_factor);
 		entry->charge_rate_previous = status->charge_rate_smoothed;
 
-		/* FIXME: following can be removed if bug #5752 of hal on freedesktop
-		   gets fixed and is part of a new release of HAL and we depend on that
-		   version */
-		if (status->charge_rate_raw == 0) {
-			status->is_discharging = FALSE;
-			status->is_charging = FALSE;
-		}
 	} else if (strcmp (key, "battery.charge_level.percentage") == 0) {
 		gpm_hal_device_get_int (power->priv->hal, udi, key, &status->percentage_charge);
 
@@ -697,9 +683,11 @@ gpm_power_status_for_device_more (GpmPowerDevice *device)
 	if (device->technology) {
 		const char *technology;
 		if (strcasecmp (device->technology, "li-ion") == 0 ||
+		    strcasecmp (device->technology, "lithium-ion") == 0 ||
 		    strcasecmp (device->technology, "lion") == 0) {
 			technology = _("Lithium ion");
-		} else if (strcasecmp (device->technology, "pbac") == 0) {
+		} else if (strcasecmp (device->technology, "pbac") == 0 ||
+			   strcasecmp (device->technology, "lead-acid") == 0) {
 			technology = _("Lead acid");
 		} else {
 			gpm_warning ("Battery type %s not translated, please report!",
@@ -978,22 +966,6 @@ battery_kind_cache_update (GpmPower		 *power,
 		type_status->is_charging = FALSE;
 	}
 
-	/* If the primary battery is neither charging nor discharging, and
-	 * the charge is low the battery is most likely broken.
-	 * In this case, we'll use the ac_adaptor to determine whether it's
-	 * charging or not. */
-	if (entry->battery_kind == GPM_POWER_KIND_PRIMARY &&
-	    (! type_status->is_charging) && (! type_status->is_discharging) &&
-	    type_status->percentage_charge > 0 &&
-	    type_status->percentage_charge < GPM_POWER_MIN_CHARGED_PERCENTAGE) {
-		gboolean on_ac;
-		on_ac = gpm_hal_is_on_ac (power->priv->hal);
-		gpm_debug ("Battery is neither charging nor discharging, "
-			   "using ac_adaptor value %i", on_ac);
-		type_status->is_charging = on_ac;
-		type_status->is_discharging = !(on_ac);
-	}
-
 	gpm_debug ("%i devices of type %s", num_present, gpm_power_kind_to_localised_string (entry->battery_kind));
 
 	/* Perform following calculations with floating point otherwise we might
@@ -1011,6 +983,22 @@ battery_kind_cache_update (GpmPower		 *power,
 		}
 		type_status->percentage_charge = pc;
 	}
+
+	/* If the primary battery is neither charging nor discharging, and
+	 * the charge is low the battery is most likely broken.
+	 * In this case, we'll use the ac_adaptor to determine whether it's
+	 * charging or not. */
+	if (entry->battery_kind == GPM_POWER_KIND_PRIMARY &&
+	    type_status->is_charging == FALSE &&
+	    type_status->is_discharging == FALSE &&
+	    type_status->percentage_charge > 0 &&
+	    type_status->percentage_charge < GPM_POWER_MIN_CHARGED_PERCENTAGE) {
+		gpm_debug ("Battery is neither charging nor discharging, "
+			   "using ac_adaptor value %i", power->priv->on_ac);
+		type_status->is_charging = power->priv->on_ac;
+		type_status->is_discharging = !(power->priv->on_ac);
+	}
+
 	/* We only do the "better" remaining time algorithm if the battery has rate,
 	   i.e not a UPS, which gives it's own battery.remaining_time but has no rate */
 	if (type_status->charge_rate_smoothed > 0) {
